@@ -15,8 +15,9 @@ class GaussianProcess( object ):
     """
     A Gaussian process.
 
-    Following notation in
-    Gaussian Processes for Machine Learning, section 2.2
+    Following notation in section 2.2 of `Gaussian Processes for Machine Learning`__ by Rasmussen and Williams. 
+
+    __ http://www.amazon.co.uk/Gaussian-Processes-Learning-Adaptive-Computation/dp/026218253X/
     """
 
     def __init__( self, X, y, k ):
@@ -190,7 +191,7 @@ class GP_LL_fn( object ):
         return result
 
 class GP_LL_deriv_fn( object ):
-    """d(LL)/d(params) as function of kernel parameters
+    """:math:`\\frac{d\\textrm{LL}}{d\\textrm{params}}` as function of kernel parameters
 
     Relies on the parameters already having been set. I.e. __call__ ignores
     its arguments!
@@ -341,7 +342,9 @@ def gp_plot_prediction(
     """
     Plot a gp's prediction using pylab including error bars if variance specified
 
-    Error bars are 2 * standard_deviation as in GP for ML book
+    Error bars are 2 * standard_deviation as in `Gaussian Processes for Machine Learning`__ by Rasmussen and Williams. 
+
+    __ http://www.amazon.co.uk/Gaussian-Processes-Learning-Adaptive-Computation/dp/026218253X/
     """
     from pylab import plot, concatenate, fill
     if None != variance:
