@@ -1,5 +1,5 @@
 #
-# Copyright John Reid 2006
+# Copyright John Reid 2006, 2012
 #
 
 
@@ -8,7 +8,9 @@ from real_kernel import *
 import numpy, math
 
 class NeuralNetworkKernel( RealKernel ):
-    """Following 4.29 in Gaussian Processes for Machine Learning
+    """Following 4.29 in `Gaussian Processes for Machine Learning`__ by Rasmussen and Williams. 
+
+    __ http://www.amazon.co.uk/Gaussian-Processes-Learning-Adaptive-Computation/dp/026218253X/
 
     No trainable paramaters
     """
