@@ -8,15 +8,13 @@ import numpy, math
 
 class RationalQuadraticKernel( RealKernel ):
     """
-    Following 4.19 in Gaussian Processes for Machine Learning
+    Following 4.19 in `Gaussian Processes for Machine Learning`__ by Rasmussen and Williams. 
 
-    From http://wiki.axiom-developer.org/SandBox8::
-    
-        \begin{axiom}
-            k := (1+r2/(2*a))**(-a)
-            differentiate(k,a)
-            differentiate(k,r)
-        \end{axiom}
+    __ http://www.amazon.co.uk/Gaussian-Processes-Learning-Adaptive-Computation/dp/026218253X/
+
+    .. math::
+        
+        k = (1 + \\frac{r^2}{2\\alpha})^{-\\alpha}
 
     Alpha is not a trainable parameter.
     The parameters are for the length scale in the r term.
@@ -63,16 +61,17 @@ class RationalQuadraticKernel( RealKernel ):
                     / 2.0
             ) * distance_2_derivative( x1, x2, self.k.params, self.i )
 
-class RationalQuadraticKernelAlphaParameterised( RealKernel ):
-    """Following 4.19 in Gaussian Processes for Machine Learning
 
-    From http://wiki.axiom-developer.org/SandBox8::
-    
-        \begin{axiom}
-            k := (1+r2/(2*a))**(-a)
-            differentiate(k,a)
-            differentiate(k,r)
-        \end{axiom}
+
+
+class RationalQuadraticKernelAlphaParameterised( RealKernel ):
+    """Following 4.19 in `Gaussian Processes for Machine Learning`__ by Rasmussen and Williams. 
+
+    __ http://www.amazon.co.uk/Gaussian-Processes-Learning-Adaptive-Computation/dp/026218253X/
+
+    .. math::
+        
+        k = (1 + \\frac{r^2}{2\\alpha})^{-\\alpha}
 
     The first parameter is alpha.
     The rest of the parameters are for the length scale in the r term.
